# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Commands for reading and manipulating packet mirroring resources."""


from googlecloudsdk.calliope import base


@base.ReleaseTracks(
    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
class PacketMirrorings(base.Group):
  """Manage Compute Engine packet mirroring resources."""


PacketMirrorings.detailed_help = {
    'brief': 'Manage Compute Engine packet mirroring resources.',
    'DESCRIPTION': 'Manage Compute Engine packet mirroring resources.',
}

PacketMirrorings.category = base.NETWORKING_CATEGORY
